@@ -22,6 +22,15 @@ import time
 
 from troveclient.i18n import _
 
+try:
+    import simplejson as json
+except ImportError:
+    import json
+
+from troveclient import exceptions
+from troveclient import utils
+from troveclient.v1 import modules
+
 INSTANCE_ARG_NAME = _('instance')
 INSTANCE_METAVAR = _('"opt=<value>[,opt=<value> ...] "')
 INSTANCE_ERROR = _("Instance argument(s) must be of the form --instance "
@@ -41,15 +50,17 @@ NIC_ERROR = _("Invalid NIC argument: %s. Must specify either net-id or port-id"
 NO_LOG_FOUND_ERROR = _("ERROR: No published '%(log_name)s' log was found for "
                        "%(instance)s.")
 LOCALITY_DOMAIN = ['affinity', 'anti-affinity']
-
-try:
-    import simplejson as json
-except ImportError:
-    import json
-
-from troveclient import exceptions
-from troveclient import utils
-from troveclient.v1 import modules
+EXT_PROPS_METAVAR = INSTANCE_METAVAR
+EXT_PROPS_HELP = _("Add extended properties for cluster create. "
+                   "Currently only support MongoDB options, other databases "
+                   "will be added in the future. "
+                   "MongoDB: "
+                   "  num_configsvr=<number_of_configsvr>, "
+                   "  num_mongos=<number_of_mongos>, "
+                   "  configsvr_volume_size=<disk_size_in_GB>, "
+                   "  configsvr_volume_type=<volume_type>, "
+                   "  mongos_volume_size=<disk_size_in_GB>, "
+                   "  mongos_volume_type=<volume_type>.")
 
 
 def _poll_for_status(poll_fn, obj_id, action, final_ok_states,
@@ -800,8 +811,8 @@ def _strip_option(opts_str, opt_name, is_required=True,
     if is_required and not opt_value:
         raise exceptions.MissingArgs([opt_name],
                                      message=(_("Missing option '%s' for "
-                                                "argument --instance ")
-                                              + INSTANCE_METAVAR))
+                                                "argument --instance ") +
+                                              INSTANCE_METAVAR))
 
     return opt_value, opts_str.strip().strip(",")
 
@@ -860,6 +871,11 @@ def _parse_instance_options(cs, instance_options, for_grow=False):
     return instances
 
 
+def _parse_extended_properties(extended_properties):
+    return dict([(k, v) for (k, v) in [kv.strip().split("=")
+                for kv in extended_properties.split(",")]])
+
+
 @utils.arg('name',
            metavar='<name>',
            type=str,
@@ -879,15 +895,30 @@ def _parse_instance_options(cs, instance_options, for_grow=False):
            choices=LOCALITY_DOMAIN,
            help=_('Locality policy to use when creating cluster. Choose '
                   'one of %(choices)s.'))
+@utils.arg('--extended_properties',
+           metavar=EXT_PROPS_METAVAR,
+           default=None,
+           help=EXT_PROPS_HELP)
+@utils.arg('--configuration',
+           metavar='<configuration>',
+           type=str,
+           default=None,
+           help=_('ID of the configuration group to attach to the cluster.'))
 @utils.service_type('database')
 def do_cluster_create(cs, args):
     """Creates a new cluster."""
     instances = _parse_instance_options(cs, args.instances)
+    extended_properties = {}
+    if args.extended_properties:
+        extended_properties = _parse_extended_properties(
+            args.extended_properties)
     cluster = cs.clusters.create(args.name,
                                  args.datastore,
                                  args.datastore_version,
                                  instances=instances,
-                                 locality=args.locality)
+                                 locality=args.locality,
+                                 extended_properties=extended_properties,
+                                 configuration=args.configuration)
     _print_cluster(cluster)
 
 
